@@ -1,5 +1,5 @@
 /* `ln' program to create links between files.
-   Copyright (C) 86, 89, 90, 91, 1995-2003 Free Software Foundation, Inc.
+   Copyright (C) 86, 89, 90, 91, 1995-2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -337,7 +337,7 @@ do_link (const char *source, const char *dest)
 void
 usage (int status)
 {
-  if (status != 0)
+  if (status != EXIT_SUCCESS)
     fprintf (stderr, _("Try `%s --help' for more information.\n"),
 	     program_name);
   else
@@ -580,5 +580,5 @@ main (int argc, char **argv)
       errors = do_link (source, new_dest);
     }
 
-  exit (errors != 0);
+  exit (errors == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
